@@ -417,6 +417,7 @@ class ModelsManager:
         # (ModelsManager_create_obj) Create base model object
         save_file = self._get_save_file(name)
         base_model = self.models[model](file_path=save_file, **parameters)
+        base_model.metadata['model'] = model
 
         # (ModelsManager_create_save) Save base model object
         with open(self._get_base_file(name), 'wb') as base_file:
@@ -970,7 +971,7 @@ class ModelsBackgroundManager:
             metadata['name'] = name
             metadata['created_at'] = datetime.now()
             metadata['updated_at'] = datetime.now()
-            metadata['model'] = instance.metadata['name']
+            metadata['model'] = instance.metadata['model'] if 'model' in instance.metadata else type(instance).__name__
             metadata['can_input'] = instance.metadata['can_input']
             metadata['can_output'] = instance.metadata['can_output']
             metadata['can_update'] = instance.metadata['can_update']
@@ -1792,8 +1793,8 @@ class ModelsMetadataManager(MetadataManager):
     
     Parameters
     ----------
-    data_manager : :class:`msdss_data_api.managers.DataManager`
-        Data manager object for managing data in a database.
+    data_manager : :class:`msdss_data_api.managers.DataManager` or None
+        Data manager object for managing data in a database. If ``None``, a default manager will be used.
         The restricted tables for the handler will be set to ``[]`` while the only permitted table will be the table name of the parameter ``table``.
     table : str
         The name of the table to store the metadata.
@@ -1871,13 +1872,14 @@ class ModelsMetadataManager(MetadataManager):
     """
     def __init__(
         self,
-        data_manager=DataManager(),
+        data_manager=None,
         table=DEFAULT_METADATA_TABLE,
         columns=DEFAULT_METADATA_COLUMNS,
         name_column=DEFAULT_NAME_COLUMN,
         updated_column=DEFAULT_UPDATE_COLUMN,
         *args, **kwargs
     ):
+        data_manager = data_manager if data_manager else DataManager()
         super().__init__(
             data_manager=data_manager,
             table=table,
